pub struct CommandPalette { /* private fields */ }Expand description
A searchable registry of Commands.
Commands are registered via CommandPalette::register and searched
via CommandPalette::search using a simple fuzzy-match algorithm
(all query characters must appear in the label in order, case-insensitive).
Implementations
Sourceimpl CommandPalette
impl CommandPalette
Sourcepub fn new() -> Self
pub fn new() -> Self
Create an empty CommandPalette.
Sourcepub fn register(
&mut self,
id: impl Into<String>,
label: impl Into<String>,
action: impl Fn() + Send + Sync + 'static,
)
pub fn register( &mut self, id: impl Into<String>, label: impl Into<String>, action: impl Fn() + Send + Sync + 'static, )
Register a command.
Sourcepub fn register_with_shortcut(
&mut self,
id: impl Into<String>,
label: impl Into<String>,
shortcut: Option<String>,
action: impl Fn() + Send + Sync + 'static,
)
pub fn register_with_shortcut( &mut self, id: impl Into<String>, label: impl Into<String>, shortcut: Option<String>, action: impl Fn() + Send + Sync + 'static, )
Register a command with an optional keyboard shortcut hint.