pub struct HotkeyRegistry { /* private fields */ }Expand description
A registry of keyboard hotkey bindings.
Enforces that no two bindings share the same (Modifiers, Key) pair.
Implementations
Sourceimpl HotkeyRegistry
impl HotkeyRegistry
Sourcepub fn new() -> Self
pub fn new() -> Self
Create an empty HotkeyRegistry.
Sourcepub fn register(
&mut self,
id: impl Into<String>,
mods: Modifiers,
key: Key,
action: impl Fn() + Send + Sync + 'static,
) -> Result<(), String>
pub fn register( &mut self, id: impl Into<String>, mods: Modifiers, key: Key, action: impl Fn() + Send + Sync + 'static, ) -> Result<(), String>
Register a hotkey binding.
Returns Err if another binding with the same (mods, key) pair
is already registered.
Sourcepub fn conflict_check(&self, mods: Modifiers, key: Key) -> bool
pub fn conflict_check(&self, mods: Modifiers, key: Key) -> bool
Returns true if a binding with this (mods, key) pair is already registered.